pywws.Localisation
==================

.. automodule:: pywws.Localisation

   .. rubric:: Functions

   .. autosummary::
   
      SetLocale   
      SetTranslation   
      SetApplicationLanguage   
